Enum sounding_base::sounding::Index
[−]
[src]
pub enum Index {
Showalter,
LI,
SWeT,
K,
LCL,
PWAT,
TotalTotals,
CAPE,
LCLTemperature,
CIN,
EquilibrimLevel,
LFC,
BulkRichardsonNumber,
Haines,
}Sounding indexes.
Note that the Sounding data type only saves indexes that may be loaded from a serialized data
format such as a .bufr file or bufkit file. But this enum supports many more indexes which
might be calculated by a sounding analysis crate. When using get_index, it will always
return a missing value if the index is not stored in this data type. If you try to set_index
with an index that is not supported by the Sounding data type, it will panic in debug mode
and silently fail in release mode.
Variants
ShowalterShowalter index
LILifted index
SWeTSevere Weather Threat Index
KK-index
LCLLifting Condensation Level, or LCL (hPa), pressure vertical coordinate.
PWATPrecipitable Water (mm)
TotalTotalsTotal-Totals
CAPEConvective Available Potential Energy, or CAPE. (J/kg)
LCLTemperatureTemperature at LCL (K)
CINConvective Inhibitive Energy, or CIN (J/kg)
EquilibrimLevelEquilibrium Level (hPa), pressure vertical coordinate
LFCLevel of Free Convection (hPa), pressure vertical coordinate
BulkRichardsonNumberBulk Richardson Number
HainesHaines index