Struct sounding_base::Sounding
[−]
[src]
pub struct Sounding {
pub num: i32,
pub valid_time: NaiveDateTime,
pub lead_time: i32,
pub lat: f32,
pub lon: f32,
pub elevation: f32,
pub show: f32,
pub li: f32,
pub swet: f32,
pub kinx: f32,
pub lclp: f32,
pub pwat: f32,
pub totl: f32,
pub cape: f32,
pub lclt: f32,
pub cins: f32,
pub eqlv: f32,
pub lfc: f32,
pub brch: f32,
pub pressure: Vec<f32>,
pub temperature: Vec<f32>,
pub wet_bulb: Vec<f32>,
pub dew_point: Vec<f32>,
pub theta_e: Vec<f32>,
pub direction: Vec<f32>,
pub speed: Vec<f32>,
pub omega: Vec<f32>,
pub height: Vec<f32>,
pub cloud_fraction: Vec<f32>,
pub mslp: f32,
pub station_pres: f32,
pub low_cloud: f32,
pub mid_cloud: f32,
pub hi_cloud: f32,
pub uwind: f32,
pub vwind: f32,
}All the variables stored in the sounding.
Missing values are -9999.0. The upper air profile variables are stored in parallel vectors. If a profile lacks a certain variable, e.g. cloud fraction, that whole vector has length 0 instead of being full of missing values.
Fields
num: i32
station number, USAF number, eg 727730
valid_time: NaiveDateTime
Valid time of sounding
lead_time: i32
Difference in model initialization time and valid_time in hours.
lat: f32
Latitude of grid point used to make sounding.
lon: f32
Longitude of grid point used to make sounding.
elevation: f32
Elevation of grid point in meters, this is in model terrain, not necessarily the same as the real world.
show: f32
Showalter index
li: f32
Lifted index
swet: f32
Severe Weather Threat Index
kinx: f32
K-index
lclp: f32
Lifting Condensation Level, or LCL (hPa), pressure vertical coordinate.
pwat: f32
Precipitable Water (mm)
totl: f32
Total-Totals
cape: f32
Convective Available Potential Energy, or CAPE. (J/kg)
lclt: f32
Temperature at LCL (K)
cins: f32
Convective Inhibitive Energy, or CIN (J/kg)
eqlv: f32
Equilibrium Level (hPa), pressure vertical coordinate
lfc: f32
Level of Free Convection (hPa), pressure vertical coordinate
brch: f32
Bulk Richardson Number
pressure: Vec<f32>
Pressure (hPa) profile
temperature: Vec<f32>
Temperature (c) profile
wet_bulb: Vec<f32>
Wet-bulb (c) profile
dew_point: Vec<f32>
Dew Point (C) profile
theta_e: Vec<f32>
Equivalent Potential Temperature (K) profile
direction: Vec<f32>
Wind direction (degrees) profile
speed: Vec<f32>
Wind speed (knots) profile
omega: Vec<f32>
Vertical velocity (Pa/sec), pressure vertical coordinate
height: Vec<f32>
Geopotential Height (m) profile
cloud_fraction: Vec<f32>
Cloud coverage fraction in percent
mslp: f32
Surface pressure reduce to mean sea level (hPa)
station_pres: f32
Surface pressure (hPa)
low_cloud: f32
Low cloud fraction
mid_cloud: f32
Mid cloud fraction
hi_cloud: f32
Hi cloud fraction
uwind: f32
U - wind speed (m/s) (West -> East is positive)
vwind: f32
V - wind speed (m/s) (South -> North is positive)