StationInfo

Struct StationInfo 

pub struct StationInfo { /* private fields */ }
๐Ÿ‘ŽDeprecated
Station information including location data and identification number.

Implementations

Source

impl StationInfo

pub fn new_with_values<T, U, V, W>( station_num: T, location: U, elevation: V, ) -> Self
where T: Into<Optioned<i32>>, U: Into<Option<(f64, f64)>>, Optioned<W>: From<V>, W: Noned + Length, Meters: From<W>,

๐Ÿ‘ŽDeprecated

Create a new StationInfo object.

Arguments

station_num: The USAF station identifier, or None.

location: The latitude and longitude as a tuple, or None.

elevation: The elevation of the station in meters.

Examples
use metfor::{Meters, Feet};
use sounding_base::StationInfo;
use optional::{some, none};

let _stn = StationInfo::new_with_values(12345, (45.2,-113.5), Meters(2000.0));
let _stn = StationInfo::new_with_values(12345, (45.2,-113.5), Feet(2000.0));
let _stn = StationInfo::new_with_values(12345, (45.2,-113.5), some(Meters(2000.0)));
let _stn = StationInfo::new_with_values(12345, (45.2,-113.5), some(Feet(2000.0)));
let _stn = StationInfo::new_with_values(12345, Some((45.2,-113.5)), Meters(2000.0));
let _stn = StationInfo::new_with_values(12345, Some((45.2,-113.5)), Feet(2000.0));
let _stn = StationInfo::new_with_values(12345, Some((45.2,-113.5)), some(Meters(2000.0)));
let _stn = StationInfo::new_with_values(12345, Some((45.2,-113.5)), some(Feet(2000.0)));
let _stn = StationInfo::new_with_values(Some(12345), None, Meters(2000.0));
let _stn = StationInfo::new_with_values(Some(12345), None, Feet(2000.0));
let _stn = StationInfo::new_with_values(None, (45.2,-113.5), some(Meters(2000.0)));
let _stn = StationInfo::new_with_values(None, (45.2,-113.5), some(Feet(2000.0)));

// Note that lat-lon is an `Option` and not an `Optioned`
let _stn = StationInfo::new_with_values(some(12345), None, none::<Feet>());
let _stn = StationInfo::new_with_values(some(12345), None, none::<Meters>());
pub fn new() -> Self

๐Ÿ‘ŽDeprecated

Create a new object with default values.

Examples
use sounding_base::StationInfo;

assert!(StationInfo::new().station_num().is_none());
assert!(StationInfo::new().location().is_none());
assert!(StationInfo::new().elevation().is_none());
pub fn with_station<T>(self, number: T) -> Self
where Optioned<i32>: From<T>,

๐Ÿ‘ŽDeprecated

Builder method to add a station number.

Examples
use sounding_base::StationInfo;

assert_eq!(StationInfo::new().with_station(12345).station_num().unwrap(), 12345);
assert_eq!(StationInfo::new().with_station(Some(12345)).station_num().unwrap(), 12345);
pub fn with_lat_lon<T>(self, coords: T) -> Self
where Option<(f64, f64)>: From<T>,

๐Ÿ‘ŽDeprecated

Builder method to add a location.

Examples
use sounding_base::StationInfo;

assert_eq!(
    StationInfo::new().with_lat_lon((45.0, -116.0)).location().unwrap(), (45.0, -116.0));
assert_eq!(
    StationInfo::new().with_lat_lon(Some((45.0, -116.0)))
        .location()
        .unwrap(),
    (45.0, -116.0));
pub fn with_elevation<T, U>(self, elev: T) -> Self
where Optioned<U>: From<T>, U: Noned + Length, Meters: From<U>,

๐Ÿ‘ŽDeprecated

Builder method to add elevation.

Examples
 use metfor::{Meters, Feet, Km};
 use sounding_base::StationInfo;
 use optional::{some, none};

 let _info = StationInfo::new().with_elevation(Feet(200.0));
 let _info = StationInfo::new().with_elevation(Meters(200.0));
 let _info = StationInfo::new().with_elevation(Km(2.0));
 let _info = StationInfo::new().with_elevation(some(Feet(200.0)));
 let _info = StationInfo::new().with_elevation(some(Meters(200.0)));
 let _info = StationInfo::new().with_elevation(some(Km(2.0)));
 let _info = StationInfo::new().with_elevation(none::<Feet>());
 let _info = StationInfo::new().with_elevation(none::<Meters>());
 let _info = StationInfo::new().with_elevation(none::<Km>());
pub fn station_num(&self) -> Optioned<i32>

๐Ÿ‘ŽDeprecated

station number, USAF number, eg 727730

pub fn location(&self) -> Option<(f64, f64)>

๐Ÿ‘ŽDeprecated

Latitude and longitude.

pub fn elevation(&self) -> Optioned<Meters>

๐Ÿ‘ŽDeprecated

Elevation in meters, this may be in model terrain, not necessarily the same as the real world.